==> scala-k8s-objects_2.12-0.3.0-sources.jar: io/k8s/api/core/v1/ServicePort.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** ServicePort contains information on service's port. */
final case class ServicePort(
  port : Int,
  nodePort : Option[Int] = None,
  name : Option[String] = None,
  targetPort : Option[io.k8s.apimachinery.pkg.util.intstr.IntOrString] = None,
  protocol : Option[String] = None,
  appProtocol : Option[String] = None
) {

  /** Returns a new data with port set to new value */
  def withPort(value: Int) : ServicePort = copy(port = value)
  /** transforms port to result of function */
  def mapPort(f: Int => Int) : ServicePort = copy(port = f(port))

  /** Returns a new data with nodePort set to new value */
  def withNodePort(value: Int) : ServicePort = copy(nodePort = Some(value))
  /** if nodePort has a value, transforms to the result of function*/
  def mapNodePort(f: Int => Int) : ServicePort = copy(nodePort = nodePort.map(f))

  /** Returns a new data with name set to new value */
  def withName(value: String) : ServicePort = copy(name = Some(value))
  /** if name has a value, transforms to the result of function*/
  def mapName(f: String => String) : ServicePort = copy(name = name.map(f))

  /** Returns a new data with targetPort set to new value */
  def withTargetPort(value: io.k8s.apimachinery.pkg.util.intstr.IntOrString) : ServicePort = copy(targetPort = Some(value))
  /** if targetPort has a value, transforms to the result of function*/
  def mapTargetPort(f: io.k8s.apimachinery.pkg.util.intstr.IntOrString => io.k8s.apimachinery.pkg.util.intstr.IntOrString) : ServicePort = copy(targetPort = targetPort.map(f))

  /** Returns a new data with protocol set to new value */
  def withProtocol(value: String) : ServicePort = copy(protocol = Some(value))
  /** if protocol has a value, transforms to the result of function*/
  def mapProtocol(f: String => String) : ServicePort = copy(protocol = protocol.map(f))

  /** Returns a new data with appProtocol set to new value */
  def withAppProtocol(value: String) : ServicePort = copy(appProtocol = Some(value))
  /** if appProtocol has a value, transforms to the result of function*/
  def mapAppProtocol(f: String => String) : ServicePort = copy(appProtocol = appProtocol.map(f))
}

object ServicePort {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.core.v1.ServicePort, T] = new Encoder[io.k8s.api.core.v1.ServicePort, T] {
        def apply(o: io.k8s.api.core.v1.ServicePort) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("port", o.port)
            .write("nodePort", o.nodePort)
            .write("name", o.name)
            .write("targetPort", o.targetPort)
            .write("protocol", o.protocol)
            .write("appProtocol", o.appProtocol)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, ServicePort] = new Decoder[T, ServicePort] {
      def apply(t: T): Either[String, ServicePort] = for {
          obj <- ObjectReader(t)
          port <- obj.read[Int]("port")
          nodePort <- obj.readOpt[Int]("nodePort")
          name <- obj.readOpt[String]("name")
          targetPort <- obj.readOpt[io.k8s.apimachinery.pkg.util.intstr.IntOrString]("targetPort")
          protocol <- obj.readOpt[String]("protocol")
          appProtocol <- obj.readOpt[String]("appProtocol")
      } yield ServicePort (
          port = port,
          nodePort = nodePort,
          name = name,
          targetPort = targetPort,
          protocol = protocol,
          appProtocol = appProtocol
        )
    }
}

==> scala-k8s-objects_3-0.16.3-sources.jar: io/k8s/api/core/v1/ServicePort.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** ServicePort contains information on service's port. */
final case class ServicePort(
  port : Int,
  nodePort : Option[Int] = None,
  name : Option[String] = None,
  targetPort : Option[io.k8s.apimachinery.pkg.util.intstr.IntOrString] = None,
  protocol : Option[String] = None,
  appProtocol : Option[String] = None
) {

  /** Returns a new data with port set to new value */
  def withPort(value: Int) : ServicePort = copy(port = value)
  /** transforms port to result of function */
  def mapPort(f: Int => Int) : ServicePort = copy(port = f(port))

  /** Returns a new data with nodePort set to new value */
  def withNodePort(value: Int) : ServicePort = copy(nodePort = Some(value))
  /** if nodePort has a value, transforms to the result of function*/
  def mapNodePort(f: Int => Int) : ServicePort = copy(nodePort = nodePort.map(f))

  /** Returns a new data with name set to new value */
  def withName(value: String) : ServicePort = copy(name = Some(value))
  /** if name has a value, transforms to the result of function*/
  def mapName(f: String => String) : ServicePort = copy(name = name.map(f))

  /** Returns a new data with targetPort set to new value */
  def withTargetPort(value: io.k8s.apimachinery.pkg.util.intstr.IntOrString) : ServicePort = copy(targetPort = Some(value))
  /** if targetPort has a value, transforms to the result of function*/
  def mapTargetPort(f: io.k8s.apimachinery.pkg.util.intstr.IntOrString => io.k8s.apimachinery.pkg.util.intstr.IntOrString) : ServicePort = copy(targetPort = targetPort.map(f))

  /** Returns a new data with protocol set to new value */
  def withProtocol(value: String) : ServicePort = copy(protocol = Some(value))
  /** if protocol has a value, transforms to the result of function*/
  def mapProtocol(f: String => String) : ServicePort = copy(protocol = protocol.map(f))

  /** Returns a new data with appProtocol set to new value */
  def withAppProtocol(value: String) : ServicePort = copy(appProtocol = Some(value))
  /** if appProtocol has a value, transforms to the result of function*/
  def mapAppProtocol(f: String => String) : ServicePort = copy(appProtocol = appProtocol.map(f))
}

object ServicePort {

    implicit val encoder : Encoder[io.k8s.api.core.v1.ServicePort] = new Encoder[io.k8s.api.core.v1.ServicePort] {
        def apply[T : Builder](o: io.k8s.api.core.v1.ServicePort) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("port", o.port)
            .write("nodePort", o.nodePort)
            .write("name", o.name)
            .write("targetPort", o.targetPort)
            .write("protocol", o.protocol)
            .write("appProtocol", o.appProtocol)
            .build
        }
    }

    implicit val decoder: Decoder[ServicePort] = new Decoder[ServicePort] {
      def apply[T : Reader](t: T): Either[String, ServicePort] = for {
          obj <- ObjectReader(t)
          port <- obj.read[Int]("port")
          nodePort <- obj.readOpt[Int]("nodePort")
          name <- obj.readOpt[String]("name")
          targetPort <- obj.readOpt[io.k8s.apimachinery.pkg.util.intstr.IntOrString]("targetPort")
          protocol <- obj.readOpt[String]("protocol")
          appProtocol <- obj.readOpt[String]("appProtocol")
      } yield ServicePort (
          port = port,
          nodePort = nodePort,
          name = name,
          targetPort = targetPort,
          protocol = protocol,
          appProtocol = appProtocol
        )
    }
}
